==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/SourceControlSecurityTokenPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.SourceControlSecurityTokenPropertiesArgs.builder
import com.pulumi.azurenative.automation.kotlin.enums.TokenType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accessToken The access token.
 * @property refreshToken The refresh token.
 * @property tokenType The token type. Must be either PersonalAccessToken or Oauth.
 */
public data class SourceControlSecurityTokenPropertiesArgs(
    public val accessToken: Output<String>? = null,
    public val refreshToken: Output<String>? = null,
    public val tokenType: Output<Either<String, TokenType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.automation.inputs.SourceControlSecurityTokenPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.automation.inputs.SourceControlSecurityTokenPropertiesArgs =
        com.pulumi.azurenative.automation.inputs.SourceControlSecurityTokenPropertiesArgs.builder()
            .accessToken(accessToken?.applyValue({ args0 -> args0 }))
            .refreshToken(refreshToken?.applyValue({ args0 -> args0 }))
            .tokenType(
                tokenType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [SourceControlSecurityTokenPropertiesArgs].
 */
@PulumiTagMarker
public class SourceControlSecurityTokenPropertiesArgsBuilder internal constructor() {
    private var accessToken: Output<String>? = null

    private var refreshToken: Output<String>? = null

    private var tokenType: Output<Either<String, TokenType>>? = null

    /**
     * @param value The access token.
     */
    @JvmName("dqvlgrdtqndaxksx")
    public suspend fun accessToken(`value`: Output<String>) {
        this.accessToken = value
    }

    /**
     * @param value The refresh token.
     */
    @JvmName("dadgllytmubforve")
    public suspend fun refreshToken(`value`: Output<String>) {
        this.refreshToken = value
    }

    /**
     * @param value The token type. Must be either PersonalAccessToken or Oauth.
     */
    @JvmName("hlwwtfjvrxddtybl")
    public suspend fun tokenType(`value`: Output<Either<String, TokenType>>) {
        this.tokenType = value
    }

    /**
     * @param value The access token.
     */
    @JvmName("ylcgnnibexprfrlw")
    public suspend fun accessToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accessToken = mapped
    }

    /**
     * @param value The refresh token.
     */
    @JvmName("xjhgdofudwufjoaj")
    public suspend fun refreshToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.refreshToken = mapped
    }

    /**
     * @param value The token type. Must be either PersonalAccessToken or Oauth.
     */
    @JvmName("xtkfwajytphiyail")
    public suspend fun tokenType(`value`: Either<String, TokenType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tokenType = mapped
    }

    /**
     * @param value The token type. Must be either PersonalAccessToken or Oauth.
     */
    @JvmName("qukofmyrfkoouiix")
    public fun tokenType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TokenType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tokenType = mapped
    }

    /**
     * @param value The token type. Must be either PersonalAccessToken or Oauth.
     */
    @JvmName("wsrpkfoexbfkoown")
    public fun tokenType(`value`: TokenType) {
        val toBeMapped = Either.ofRight<String, TokenType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tokenType = mapped
    }

    internal fun build(): SourceControlSecurityTokenPropertiesArgs =
        SourceControlSecurityTokenPropertiesArgs(
            accessToken = accessToken,
            refreshToken = refreshToken,
            tokenType = tokenType,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/SourceControlSecurityTokenPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.SourceControlSecurityTokenPropertiesArgs.builder
import com.pulumi.azurenative.automation.kotlin.enums.TokenType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accessToken The access token.
 * @property refreshToken The refresh token.
 * @property tokenType The token type. Must be either PersonalAccessToken or Oauth.
 */
public data class SourceControlSecurityTokenPropertiesArgs(
    public val accessToken: Output<String>? = null,
    public val refreshToken: Output<String>? = null,
    public val tokenType: Output<Either<String, TokenType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.automation.inputs.SourceControlSecurityTokenPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.automation.inputs.SourceControlSecurityTokenPropertiesArgs =
        com.pulumi.azurenative.automation.inputs.SourceControlSecurityTokenPropertiesArgs.builder()
            .accessToken(accessToken?.applyValue({ args0 -> args0 }))
            .refreshToken(refreshToken?.applyValue({ args0 -> args0 }))
            .tokenType(
                tokenType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [SourceControlSecurityTokenPropertiesArgs].
 */
@PulumiTagMarker
public class SourceControlSecurityTokenPropertiesArgsBuilder internal constructor() {
    private var accessToken: Output<String>? = null

    private var refreshToken: Output<String>? = null

    private var tokenType: Output<Either<String, TokenType>>? = null

    /**
     * @param value The access token.
     */
    @JvmName("kjbmrdhsdialsroc")
    public suspend fun accessToken(`value`: Output<String>) {
        this.accessToken = value
    }

    /**
     * @param value The refresh token.
     */
    @JvmName("aurqlvmtvbeutwve")
    public suspend fun refreshToken(`value`: Output<String>) {
        this.refreshToken = value
    }

    /**
     * @param value The token type. Must be either PersonalAccessToken or Oauth.
     */
    @JvmName("oygkrymveuptcvxs")
    public suspend fun tokenType(`value`: Output<Either<String, TokenType>>) {
        this.tokenType = value
    }

    /**
     * @param value The access token.
     */
    @JvmName("dbcuwokubaenbnna")
    public suspend fun accessToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accessToken = mapped
    }

    /**
     * @param value The refresh token.
     */
    @JvmName("ppprldbmwqtlitqa")
    public suspend fun refreshToken(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.refreshToken = mapped
    }

    /**
     * @param value The token type. Must be either PersonalAccessToken or Oauth.
     */
    @JvmName("kyaiphcttkglwdgm")
    public suspend fun tokenType(`value`: Either<String, TokenType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tokenType = mapped
    }

    /**
     * @param value The token type. Must be either PersonalAccessToken or Oauth.
     */
    @JvmName("lvyfsachhuinjhbk")
    public fun tokenType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TokenType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tokenType = mapped
    }

    /**
     * @param value The token type. Must be either PersonalAccessToken or Oauth.
     */
    @JvmName("iqwttmxpcuqhyyot")
    public fun tokenType(`value`: TokenType) {
        val toBeMapped = Either.ofRight<String, TokenType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tokenType = mapped
    }

    internal fun build(): SourceControlSecurityTokenPropertiesArgs =
        SourceControlSecurityTokenPropertiesArgs(
            accessToken = accessToken,
            refreshToken = refreshToken,
            tokenType = tokenType,
        )
}
